@@ -442,7 +442,13 @@ static FvwmWindow *Circulate(char *action, int Direction, char **restofline)
       fw = sf;
   }
   else
+  {
+    if (Direction == 0)
+    {
+      return NULL;
+    }
     fw = NULL;
+  }
 
   for (pass = 0; pass < 3 && !found; pass++)
   {
@@ -773,6 +779,8 @@ void CMD_Pick(F_CMD_ARGS)
 
   flags = CreateFlagString(action, &restofline);
   DefaultConditionMask(&mask);
+  mask.my_flags.use_circulate_hit = 1;
+  mask.my_flags.use_circulate_hit_icon = 1;
   CreateConditionMask(flags, &mask);
   if (flags)
     free(flags);
@@ -781,6 +789,39 @@ void CMD_Pick(F_CMD_ARGS)
     old_execute_function(
       restofline, tmp_win, eventp, C_WINDOW, *Module, 0, NULL);
   }
+  FreeConditionMask(&mask);
+}
+
+void CMD_ThisWindow(F_CMD_ARGS)
+{
+	char *restofline;
+	char *flags;
+	WindowConditionMask mask;
+
+	if (!tmp_win)
+	{
+		return;
+	}
+
+	flags = CreateFlagString(action, &restofline);
+	DefaultConditionMask(&mask);
+	mask.my_flags.use_circulate_hit = 1;
+	mask.my_flags.use_circulate_hit_icon = 1;
+	CreateConditionMask(flags, &mask);
+	if (flags)
+	{
+		free(flags);
+	}
+
+	if (MatchesConditionMask(tmp_win, &mask) && restofline)
+	{
+		old_execute_function(
+			restofline, tmp_win, eventp, C_WINDOW, *Module, 0,
+			NULL);
+	}
+
+	FreeConditionMask(&mask);
+	return;
 }
 
 void CMD_WindowId(F_CMD_ARGS)
