@@ -247,8 +247,10 @@ static int Get_TBLR(char *token, unsigned char *IconFill)
  *  Inputs:
  *      merged_style - style resulting from the merge
  *      add_style    - the style to be added into the merge_style
- *      do_free      - free allocated parts of merge_style that are replaced
- +                     from add_style
+ *      do_free_src_and_alloc_copy
+ *                   - free allocated parts of merge_style that are replaced
+ *                     from add_style.  Create a copy of of the replaced
+ *                     styles in allocated memory.
  *
  *  Note:
  *      The only trick here is that on and off flags/buttons are
@@ -257,7 +259,8 @@ static int Get_TBLR(char *token, unsigned char *IconFill)
  ***********************************************************************/
 
 static void merge_styles(
-  window_style *merged_style, window_style *add_style, Bool do_free)
+  window_style *merged_style, window_style *add_style,
+  Bool do_free_src_and_alloc_copy)
 {
   int i;
   char *merge_flags;
@@ -269,7 +272,7 @@ static void merge_styles(
 
   if (add_style->flag_mask.has_icon)
   {
-    if (do_free)
+    if (do_free_src_and_alloc_copy)
     {
       SAFEFREE(SGET_ICON_NAME(*merged_style));
       SSET_ICON_NAME(*merged_style, (SGET_ICON_NAME(*add_style)) ?
@@ -283,7 +286,7 @@ static void merge_styles(
 #ifdef MINI_ICONS
   if (add_style->flag_mask.has_mini_icon)
   {
-    if (do_free)
+    if (do_free_src_and_alloc_copy)
     {
       SAFEFREE(SGET_MINI_ICON_NAME(*merged_style));
       SSET_MINI_ICON_NAME(*merged_style, (SGET_MINI_ICON_NAME(*add_style)) ?
@@ -298,7 +301,7 @@ static void merge_styles(
 #ifdef USEDECOR
   if (add_style->flag_mask.has_decor)
   {
-    if (do_free)
+    if (do_free_src_and_alloc_copy)
     {
       SAFEFREE(SGET_DECOR_NAME(*merged_style));
       SSET_DECOR_NAME(*merged_style, (SGET_DECOR_NAME(*add_style)) ?
@@ -312,7 +315,7 @@ static void merge_styles(
 #endif
   if (SFHAS_ICON_FONT(*add_style))
   {
-    if (do_free)
+    if (do_free_src_and_alloc_copy)
     {
       SAFEFREE(SGET_ICON_FONT(*merged_style));
       SSET_ICON_FONT(*merged_style, (SGET_ICON_FONT(*add_style)) ?
@@ -325,7 +328,7 @@ static void merge_styles(
   }
   if (SFHAS_WINDOW_FONT(*add_style))
   {
-    if (do_free)
+    if (do_free_src_and_alloc_copy)
     {
       SAFEFREE(SGET_WINDOW_FONT(*merged_style));
       SSET_WINDOW_FONT(*merged_style, (SGET_WINDOW_FONT(*add_style)) ?
@@ -348,7 +351,7 @@ static void merge_styles(
   }
   if (add_style->flag_mask.has_color_fore)
   {
-    if (do_free)
+    if (do_free_src_and_alloc_copy)
     {
       SAFEFREE(SGET_FORE_COLOR_NAME(*merged_style));
       SSET_FORE_COLOR_NAME(*merged_style, (SGET_FORE_COLOR_NAME(*add_style)) ?
@@ -361,7 +364,7 @@ static void merge_styles(
   }
   if (add_style->flag_mask.has_color_back)
   {
-    if (do_free)
+    if (do_free_src_and_alloc_copy)
     {
       SAFEFREE(SGET_BACK_COLOR_NAME(*merged_style));
       SSET_BACK_COLOR_NAME(*merged_style, (SGET_BACK_COLOR_NAME(*add_style)) ?
@@ -374,11 +377,12 @@ static void merge_styles(
   }
   if (add_style->flag_mask.has_color_fore_hi)
   {
-    if (do_free)
+    if (do_free_src_and_alloc_copy)
     {
       SAFEFREE(SGET_FORE_COLOR_NAME_HI(*merged_style));
       SSET_FORE_COLOR_NAME_HI(
-	*merged_style, SGET_FORE_COLOR_NAME_HI(*add_style));
+        *merged_style, (SGET_FORE_COLOR_NAME_HI(*add_style)) ?
+        safestrdup(SGET_FORE_COLOR_NAME_HI(*add_style)) : NULL);
     }
     else
     {
@@ -388,11 +392,12 @@ static void merge_styles(
   }
   if (add_style->flag_mask.has_color_back_hi)
   {
-    if (do_free)
+    if (do_free_src_and_alloc_copy)
     {
       SAFEFREE(SGET_BACK_COLOR_NAME_HI(*merged_style));
       SSET_BACK_COLOR_NAME_HI(
-	*merged_style, SGET_BACK_COLOR_NAME_HI(*add_style));
+        *merged_style, (SGET_BACK_COLOR_NAME_HI(*add_style)) ?
+        safestrdup(SGET_BACK_COLOR_NAME_HI(*add_style)) : NULL);
     }
     else
     {
@@ -400,20 +405,20 @@ static void merge_styles(
 	*merged_style, SGET_BACK_COLOR_NAME_HI(*add_style));
     }
   }
-  if(add_style->flags.has_border_width)
+  if (add_style->flags.has_border_width)
   {
     SSET_BORDER_WIDTH(*merged_style, SGET_BORDER_WIDTH(*add_style));
   }
-  if(add_style->flags.has_handle_width)
+  if (add_style->flags.has_handle_width)
   {
     SSET_HANDLE_WIDTH(*merged_style, SGET_HANDLE_WIDTH(*add_style));
   }
-  if(add_style->flags.has_max_window_size)
+  if (add_style->flags.has_max_window_size)
   {
     SSET_MAX_WINDOW_WIDTH(*merged_style, SGET_MAX_WINDOW_WIDTH(*add_style));
     SSET_MAX_WINDOW_HEIGHT(*merged_style, SGET_MAX_WINDOW_HEIGHT(*add_style));
   }
-  if(add_style->flags.has_window_shade_steps)
+  if (add_style->flags.has_window_shade_steps)
   {
     SSET_WINDOW_SHADE_STEPS(*merged_style, SGET_WINDOW_SHADE_STEPS(*add_style));
   }
@@ -424,7 +429,7 @@ static void merge_styles(
   {
     /* If style has iconboxes */
     /* copy it */
-    if (do_free)
+    if (do_free_src_and_alloc_copy)
     {
       remove_icon_boxes_from_style(merged_style);
       copy_icon_boxes(
@@ -973,16 +978,23 @@ void CMD_Style(F_CMD_ARGS)
         else if (StrEquals(token, "BackingStore"))
         {
           found = True;
-	  ptmpstyle->flags.use_backing_store = 1;
-	  ptmpstyle->flag_mask.use_backing_store = 1;
-	  ptmpstyle->change_mask.use_backing_store = 1;
+	  ptmpstyle->flags.use_backing_store = BACKINGSTORE_ON;
+	  ptmpstyle->flag_mask.use_backing_store = BACKINGSTORE_MASK;
+	  ptmpstyle->change_mask.use_backing_store = BACKINGSTORE_MASK;
         }
         else if (StrEquals(token, "BackingStoreOff"))
         {
           found = True;
-	  ptmpstyle->flags.use_backing_store = 0;
-	  ptmpstyle->flag_mask.use_backing_store = 1;
-	  ptmpstyle->change_mask.use_backing_store = 1;
+	  ptmpstyle->flags.use_backing_store = BACKINGSTORE_OFF;
+	  ptmpstyle->flag_mask.use_backing_store = BACKINGSTORE_MASK;
+	  ptmpstyle->change_mask.use_backing_store = BACKINGSTORE_MASK;
+        }
+        else if (StrEquals(token, "BackingStoreWindowDefault"))
+        {
+          found = True;
+	  ptmpstyle->flags.use_backing_store = BACKINGSTORE_DEFAULT;
+	  ptmpstyle->flag_mask.use_backing_store = BACKINGSTORE_MASK;
+	  ptmpstyle->change_mask.use_backing_store = BACKINGSTORE_MASK;
         }
 	else if (StrEquals(token, "BorderColorset"))
 	{
@@ -2700,7 +2712,7 @@ void CMD_Style(F_CMD_ARGS)
   {
     /* merge with previous style */
     merge_styles(last_style_in_list, ptmpstyle, True);
-    free(SGET_NAME(*ptmpstyle));
+    free_style(ptmpstyle);
     free(ptmpstyle);
   }
   else
@@ -2742,7 +2754,7 @@ void check_window_style_change(
 
   if (IS_STYLE_DELETED(t))
   {
-    /* updfate all styles */
+    /* update all styles */
     memset(flags, 0xff, sizeof(*flags));
     SET_STYLE_DELETED(t, 0);
     return;
@@ -2881,7 +2893,6 @@ void check_window_style_change(
     flags->do_update_modules_flags = True;
   }
 
-
   /*
    *   has_icon_boxes
    */
