@@ -226,6 +226,7 @@ static void apply_window_updates(
     if (focus_w == t)
       flags->do_redraw_decoration = True;
     update_window_color_hi_style(t, pstyle);
+    flags->do_broadcast_focus = True;
   }
   if (flags->do_redraw_decoration)
   {
@@ -287,6 +288,15 @@ static void apply_window_updates(
   {
     BroadcastConfig(M_CONFIGURE_WINDOW,t);
   }
+  if (flags->do_broadcast_focus)
+  {
+    if (Scr.Hilite != NULL && t == Scr.Hilite)
+    {
+      BroadcastPacket(
+	M_FOCUS_CHANGE, 5, Scr.Hilite->w, Scr.Hilite->frame, 0,
+	Scr.Hilite->hicolors.fore, Scr.Hilite->hicolors.back);
+    }
+  }
   t->shade_anim_steps = pstyle->shade_anim_steps;
 
   return;
