@@ -466,6 +466,9 @@ void GrabAllWindowKeysAndButtons(Display *dpy, Window w, Binding *blist,
 				 unsigned int contexts,
 				 unsigned int dead_modifiers,
 				 Cursor cursor, Bool fGrab);
+void GrabWindowKeyOrButton(
+  Display *dpy, Window w, Binding *binding, unsigned int contexts,
+  unsigned int dead_modifiers, Cursor cursor, Bool fGrab);
 KeySym FvwmStringToKeysym(Display *dpy, char *key);
 
 /***********************************************************************
@@ -474,7 +477,7 @@ KeySym FvwmStringToKeysym(Display *dpy, char *key);
 
 void fvwmlib_keyboard_shortcuts(
     Display *dpy, int screen, XEvent *Event, int x_move_size, int y_move_size,
-    int ReturnEvent);
+    int *x_defect, int *y_defect, int ReturnEvent);
 
 void fvwmlib_get_target_window(
     Display *dpy, int screen, char *MyName, Window *app_win,
@@ -482,6 +485,11 @@ void fvwmlib_get_target_window(
 
 Window fvwmlib_client_window(Display *dpy, Window input);
 
+/***********************************************************************
+ * Cursor.c
+ ***********************************************************************/
+
+int fvwmCursorNameToIndex (char *cursor_name);
 
 /* Set up heap debugging library dmalloc.  */
 
