@@ -119,9 +119,11 @@ void MakeButton(button_info *b)
     exit(2);
   }
 
-  if(!(b->flags & b_Icon) &&
-     (buttonSwallowCount(b) < 3 || (b->flags & b_Panel)))
+  if ((b->flags & b_Swallow) && !(b->flags & b_Icon) &&
+      buttonSwallowCount(b) < 3)
+  {
     return;
+  }
 
   /* Check if parent container has an icon as background */
   if (b->parent->c->flags&b_IconBack || b->parent->c->flags&b_IconParent)
