@@ -37,6 +37,8 @@
 #include <X11/Xlib.h>
 #include <X11/Intrinsic.h>
 
+#include "libs/fvwmlib.h"
+#include "libs/FScreen.h"
 #include "libs/Module.h"
 #include "libs/Colorset.h"
 #include "FvwmButtons.h"
@@ -1075,7 +1077,7 @@ static void ParseButton(button_info **uberb,char *s)
           char *r;
           char *u = s;
 
-          s = GetQuotedString(s, &t, ",)", NULL, NULL, NULL);
+          s = GetQuotedString(s, &t, ",)", NULL, "(", ")");
           r = s;
           if (t && r > u + 1)
           {
@@ -1631,7 +1633,7 @@ void parse_window_geometry(char *geom)
   unsigned int width;
   unsigned int height;
 
-  flags = XParseGeometry(geom,&g_x,&g_y,&width,&height);
+  flags = FScreenParseGeometry(geom,&g_x,&g_y,&width,&height);
   UberButton->w = 0;
   UberButton->h = 0;
   if (flags&WidthValue)
@@ -1664,6 +1666,7 @@ void ParseConfiguration(button_info *ub)
     "imagepath",
     "colorlimit",
     "colorset",
+    XINERAMA_CONFIG_STRING,
     NULL
   };
 
@@ -1695,6 +1698,10 @@ void ParseConfiguration(button_info *ub)
       /* store colorset sent by fvwm */
       LoadColorset(rest);
       break;
+    case 4:
+      /* Xinerama state */
+      FScreenConfigureModule(rest);
+      break;
     }
     GetConfigLine(fd,&s);
   }
