@@ -1,6 +1,6 @@
 /*
-   FvwmButtons, copyright 1996, Jarl Totland
-
+ * FvwmButtons, copyright 1996, Jarl Totland
+ *
  * This module, and the entire GoodStuff program, and the concept for
  * interfacing this module to the Window Manager, are all original work
  * by Robert Nation
@@ -9,8 +9,8 @@
  * are provided or implied in any way whatsoever. Use this program at your
  * own risk. Permission to use this program for any purpose is given,
  * as long as the copyright is kept intact.
-
-*/
+ *
+ */
 
 /* This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,6 +27,6 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-void ParseOptions(button_info*);
-
-
+void ParseConfiguration(button_info *ub);
+void parse_window_geometry(char *geom);
+char *expand_action(char *in_action, button_info *b);
