@@ -27,11 +27,6 @@
 #include "libs/Module.h"
 
 
-static char *IM_VERSION = "1.3";
-
-static char const rcsid[] =
-  "$Id: FvwmIconMan.c,v 1.34 2001/04/14 22:52:57 olicha Exp $";
-
 const char *MyName;
 
 static RETSIGTYPE TerminateHandler(int);
@@ -206,7 +201,8 @@ main(int argc, char **argv)
 
   if (argc == 7)
   {
-    if (strcasecmp (argv[6], "Transient")==0)
+    if (strcasecmp (argv[6], "Transient")==0 ||
+	strcasecmp (argv[6], "-Transient")==0)
       globals.transient = 1;
     else
     {
@@ -220,8 +216,8 @@ main(int argc, char **argv)
 
   if(argc < 6)
   {
-    fprintf(stderr,"%s Version %s should only be executed by fvwm!\n",Module,
-      IM_VERSION);
+    fprintf(stderr, "%s version %s should only be executed by fvwm!\n",
+      Module, VERSION);
     ShutMeDown(1);
   }
   Fvwm_fd[0] = atoi(argv[1]);
