@@ -19,10 +19,12 @@
 #include "x.h"
 #include "xmanager.h"
 
+#include <libs/fvwmlib.h>
+#include <libs/FScreen.h>
 #include <libs/Module.h>
 
 static char const rcsid[] =
-  "$Id: fvwm.c,v 1.30 2001/03/14 00:36:38 domivogt Exp $";
+  "$Id: fvwm.c,v 1.34 2001/08/26 12:43:26 domivogt Exp $";
 
 static WinData *fvwm_focus_win = NULL;
 
@@ -146,6 +148,7 @@ int win_in_viewport (WinData *win)
 {
   WinManager *manager = win->manager;
   int flag = 0;
+  int reverse = 0;
 
   assert (manager);
 
@@ -154,35 +157,44 @@ int win_in_viewport (WinData *win)
     flag = 1;
     break;
 
+  case NO_SHOW_DESKTOP:
+    reverse = 1;
+    /* fall through to next case */
   case SHOW_DESKTOP:
-    if ((IS_STICKY(win)) || win->desknum == globals.desknum)
+    if (IS_STICKY(win) || win->desknum == globals.desknum)
       flag = 1;
     break;
 
+  case NO_SHOW_PAGE:
+    reverse = 1;
+    /* fall through to next case */
   case SHOW_PAGE:
     if (IS_STICKY(win)) {
       flag = 1;
     } else if (win->desknum == globals.desknum) {
       /* win and screen intersect if they are not disjoint in x and y */
-      flag = RECTANGLES_INTERSECT (win->x, win->y, win->width, win->height,
-				   0, 0, globals.screenx, globals.screeny);
+      flag = RECTANGLES_INTERSECT(
+	win->x, win->y, win->width, win->height,
+	manager->managed_g.x, manager->managed_g.y,
+	manager->managed_g.width, manager->managed_g.height);
     }
     break;
 
-  case NO_SHOW_DESKTOP:
-    /* Show the window if it's not on the current desk */
-    if (!(IS_STICKY(win)) && win->desknum != globals.desknum)
-      flag = 1;
+  case NO_SHOW_SCREEN:
+    reverse = 1;
+    /* fall through to next case */
+  case SHOW_SCREEN:
+    if (win->desknum == globals.desknum) {
+      /* win and screen intersect if they are not disjoint in x and y */
+      flag = RECTANGLES_INTERSECT(
+	win->x, win->y, win->width, win->height,
+	manager->managed_g.x, manager->managed_g.y,
+	manager->managed_g.width, manager->managed_g.height);
+    }
     break;
-
-  case NO_SHOW_PAGE:
-    /* Show the window if it's not in the viewport (on the page) */
-    if (!(IS_STICKY(win)) &&
-	 ( win->desknum != globals.desknum ||
-	   !(RECTANGLES_INTERSECT (win->x, win->y, win->width, win->height,
-      				   0, 0, globals.screenx, globals.screeny))))
-      flag = 1;
   }
+  flag ^= reverse;
+
   return flag;
 }
 
@@ -211,17 +223,22 @@ static void set_win_configuration (WinData *win, FvwmPacketBody *body)
   memcpy(&(win->flags), &(body->add_config_data.flags), sizeof(win->flags));
 }
 
-static void configure_colorsets (unsigned long *body)
+static void handle_config_info (unsigned long *body)
 {
   char *tline, *token;
   int color;
 
   tline = (char*)&(body[3]);
   token = PeekToken(tline, &tline);
-  if (StrEquals(token, "Colorset")) {
+  if (StrEquals(token, "Colorset"))
+  {
     color = LoadColorset(tline);
     change_colorset(color);
   }
+  else if (StrEquals(token, XINERAMA_CONFIG_STRING))
+  {
+    FScreenConfigureModule(tline);
+  }
 }
 
 static void configure_window (FvwmPacketBody *body)
@@ -377,7 +394,7 @@ static void new_window (FvwmPacketBody *body)
   }
   else
   {
-    free(win);
+    Free(win);
   }
 }
 
@@ -470,7 +487,7 @@ static void ProcessMessage (Ulong type, FvwmPacketBody *body)
   {
   case M_CONFIG_INFO:
     ConsoleDebug (FVWM, "DEBUG::M_CONFIG_INFO\n");
-    configure_colorsets ((unsigned long*)body);
+    handle_config_info ((unsigned long*)body);
     break;
 
   case M_CONFIGURE_WINDOW:
@@ -597,17 +614,19 @@ static void ProcessMessage (Ulong type, FvwmPacketBody *body)
 
 void ReadFvwmPipe (void)
 {
-    FvwmPacket* packet;
+  FvwmPacket* packet;
 
-    PrintMemuse();
-    ConsoleDebug(FVWM, "DEBUG: entering ReadFvwmPipe\n");
+  PrintMemuse();
+  ConsoleDebug(FVWM, "DEBUG: entering ReadFvwmPipe\n");
 
-    if ( (packet = ReadFvwmPacket(Fvwm_fd[1])) == NULL )
-    {
-	exit(0);
-    }
-    else
-	ProcessMessage( packet->type, (FvwmPacketBody*) packet->body );
+  if ( (packet = ReadFvwmPacket(Fvwm_fd[1])) == NULL )
+  {
+    exit(0);
+  }
+  else
+  {
+    ProcessMessage( packet->type, (FvwmPacketBody*) packet->body );
+  }
 
-    ConsoleDebug(FVWM, "DEBUG: leaving ReadFvwmPipe\n");
+  ConsoleDebug(FVWM, "DEBUG: leaving ReadFvwmPipe\n");
 }
